@@ -17,7 +17,6 @@ AGENT_LIB=${HINEMOS_AGENT_HOME}/lib
 AGENT_CONF=${HINEMOS_AGENT_HOME}/conf
 TIMEOUT=3
 export PROG=`basename $0`
-export HINEMOS_AGENT_HOME=${HINEMOS_AGENT_HOME}
 
 # Logging
 function Logging() {
@@ -68,24 +67,35 @@ then
         exit 1
 fi
 
-## tune JVM Heap Memory
-JAVA_OPTS="-Xms32m -Xmx32m"
+# check version and module
+STDOUT=${HINEMOS_AGENT_HOME}/var/log/agent_stdout.log
+STDERR=${HINEMOS_AGENT_HOME}/var/log/agent_stderr.log
 
-## JVM GC logging
-#DATE_POSTFIX=""
-#DATE_POSTFIX=".`date +%Y-%m-%d-%H%M%S`"
-#JAVA_OPTS="${JAVA_OPTS} -Xloggc:${HINEMOS_AGENT_HOME}/var/log/agent_gc.log${DATE_POSTFIX} -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps -XX:+PrintClassHistogram"
+echo > ${STDOUT}
+echo > ${STDERR}
 
-## for jconsole
-#JAVA_OPTS="${JAVA_OPTS} -Dcom.sun.management.jmxremote -Dcom.sun.management.jmxremote.port=7102 -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.authenticate=false"
+echo "##############################" >> ${STDOUT}
+echo "HinemosAgent Info" >> ${STDOUT}
+echo "##############################" >> ${STDOUT}
+echo OutputDate:`date +%Y%m%d%H%M%S` >> ${STDOUT}
+echo VersionFile:`cat ${HINEMOS_AGENT_HOME}/_version` >> ${STDOUT}
+echo SerialFile:`cat ${HINEMOS_AGENT_HOME}/var/_serial` >> ${STDOUT}
+echo JavaVersion: >> ${STDOUT}
+echo `${JAVA_HOME}/bin/java -version 2>&1` >> ${STDOUT}
+echo PackageFile\(MD5\): >> ${STDOUT}
+md5sum ${HINEMOS_AGENT_HOME}/lib/Hinemos*.jar >> ${STDOUT}
+md5sum ${HINEMOS_AGENT_HOME}/lib/AgentWS.jar >> ${STDOUT}
 
-## for OutOfMemory
-JAVA_OPTS="${JAVA_OPTS} -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=${HINEMOS_AGENT_HOME}/var/log"
-export _JAVA_OPTIONS="-XX:OnOutOfMemoryError='$JAVA_HOME/bin/jmap -histo %p >> ${HINEMOS_AGENT_HOME}/var/log/agent_outofmemory_histgram.log'"
-
-## for hostname
-HOSTNAME=`hostname`
-JAVA_OPTS="${JAVA_OPTS} -Dhostname=${HOSTNAME}"
+# java option
+JAVA_OPTS="${JAVA_OPTS} -server"
+JAVA_OPTS="${JAVA_OPTS} ${JVM_HEAP_OPTS}"
+JAVA_OPTS="${JAVA_OPTS} -Dhinemos.agent.log.dir=${HINEMOS_AGENT_LOG_DIR}"
+JAVA_OPTS="${JAVA_OPTS} -XX:CMSInitiatingOccupancyFraction=75 -XX:+UseCMSInitiatingOccupancyOnly"
+JAVA_OPTS="${JAVA_OPTS} -XX:+UseConcMarkSweepGC -XX:+CMSParallelRemarkEnabled -XX:+UseParNewGC -XX:+DisableExplicitGC"
+JAVA_OPTS="${JAVA_OPTS} -XX:SurvivorRatio=3 -XX:MaxTenuringThreshold=32 -XX:TargetSurvivorRatio=90"
+JAVA_OPTS="${JAVA_OPTS} ${JVM_GCLOG_OPTS}"
+JAVA_OPTS="${JAVA_OPTS} ${JVM_JCONSOLE_OPTS}"
+JAVA_OPTS="${JAVA_OPTS} ${JVM_OOM_OPTS}"
 
 ## classpath (java)
 CP="${AGENT_LIB}/AgentWS.jar"
@@ -97,8 +107,8 @@ CP="${CP}:${AGENT_CONF}"
 
 ## startup
 CMD="nohup ${JAVA_HOME}/bin/java ${JAVA_OPTS} -cp ${CP} com.clustercontrol.agent.Agent ${AGENT_CONF}/Agent.properties ${AGENT_CONF}/log4j.properties"
-echo $CMD > ${HINEMOS_AGENT_HOME}/var/log/agent_stdouterr.log
-$CMD >> ${HINEMOS_AGENT_HOME}/var/log/agent_stdouterr.log 2>&1 &
+echo $CMD >> ${STDOUT}
+$CMD >> ${STDOUT} 2>> ${STDERR} &
 echo $! > ${HINEMOS_AGENT_PID}
 
 ## check process
@@ -114,4 +124,4 @@ do
 done
 
 Logging "Hinemos Agent startup failed."
-exit 1
\ No newline at end of file
+exit 1
